TODO List
=========

In decreasing order of importance.


Write tests!
------------

Self-explanatory.


Write a man page
----------------

Self-explanatory.


Suggestion: Highlight label names in error messages
---------------------------------------------------

In error messages like `workspace is not a valid label.` would be nice
to have the word "workspace" in another color to ease the reading.
